#  Copyright 2021-2025 ZBW – Leibniz Information Centre for Economics
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.
from typing import List

from sklearn.base import RegressorMixin, BaseEstimator

from qualle.models import Documents, Labels


class AbstractLabelCalibrator(BaseEstimator, RegressorMixin):
    def fit(self, X: Documents, y: List[Labels]):
        pass  # pragma: no cover

    def predict(self, X: Documents):
        pass  # pragma: no cover
